/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.generator;

import org.enhydra.zeus.ZeusException;

/**
 * <p>
 *  <code>IllegalOutputDirectoryException</code> is an extension of 
 *    <code>{@link ZeusException}</code> that provides information
 *    about an illegal directory specification.
 * </p>
 * 
 * @author Brett McLaughlin
 */
public class IllegalOutputDirectoryException extends ZeusException {
    
    /**
     * <p>
     *  This indicates that an invalid output directory was supplied.
     * </p>
     */    
    public IllegalOutputDirectoryException()  {
        super("An illegal output directory was specified.");
    }
    
    /**
     * <p>
     *  This indicates that an invalid output directory was supplied.
     * </p>
     *
     * @param directoryName the path of the directory supplied.
     */    
    public IllegalOutputDirectoryException(String directoryName)  {
        super("An illegal output directory, '" + directoryName +
            "', was specified.");
    }
}
