/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.transform;

import org.enhydra.zeus.ZeusException;

/**
 * <p>
 *  <code>TransformerException</code> is an extension of 
 *    <code>{@link ZeusException}</code> that provides exceptions specific to
 *    the problems that Zeus <code>{@link org.enhydra.zeus.Transformer}</code> 
 *    and related classes may throw. This is generally associated with the
 *    <code>org.enhydra.zeus.transform</code> package of the Zeus distribution.
 * </p>
 * 
 * @author Brett McLaughlin
 */
public class TransformerException extends ZeusException {
    
    /**
     * <p>
     *  This will create a <code>TransformerException</code>.
     * </p>
     */
    public TransformerException() {
        super("An exception occurred in Zeus transformation processing.");
    }
    
    /**
     * <p>
     *  This will create a <code>TransformerException</code> with the given 
     *    message.
     * </p>
     *
     * @param message <code>String</code> message indicating
     *                the problem that occurred.
     */    
    public TransformerException(String message)  {
        super(message);
    }

    /**
     * <p>
     *  This will create an <code>Exception</code> with the given message
     *    and wrap another <code>Exception</code>.  This is useful when
     *    the originating <code>Exception</code> should be held on to.
     * </p>
     *
     * @param message <code>String</code> message indicating
     *                the problem that occurred.
     * @param cause <code>Throwable</code> that caused this
     *                  to be thrown.
     */    
    public TransformerException(String message, Throwable cause)  {
        super(message);    
        this.cause = cause;
    }
}
