/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  <code>AbstractBinderTest</code> is an abstract test class that will 
 *    be inherited by all test classes designed to test the Zeus binders.
 * </p>
 *
 * @author Sean Ogle
 */
public abstract class AbstractBinderTest extends TestCase {

    /**
     * <p>
     *  This creates a new Binder to test.
     * </p>
     *
     * @return <code>Binder</code> - the created <code>Binder</code>
     */
    public abstract Binder createBinder();

    /**
     * <p>
     *  This creates the new <code>Binder</code>.
     * </p>
     *
     * @param name the name to give the test in reports.
     */
    public AbstractBinderTest(String name) {
        super(name);
    }
    
    /**
     * <p>
     *  This method maeks it easier to call these
     *    tests dynamically.
     * </p>
     *
     * @return <code>TestSuite</code> - corresponds to this 
     *         <code>TestCase</code>.
     */
    public static Test suite() {
        return new TestSuite(AbstractBinderTest.class);
    }
}
