/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.binding;

import java.util.BitSet;
import java.util.Vector;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  This is a test case for the <code>{@link ContainerProperty}</code> class.
 * </p><p>
 *  Even though <code>ContainerProperty</code> implements both 
 *    <code>{@link Property}</code> and <code>{@link Container}</code>,
 *    <code>ContainerPropertyTest</code> will only provide a concrete 
 *    <code>{@link AbstractContainerTest}</code>. 
 *    <code>{@link AtomicPropertyTest}</code> already provides a concrete 
 *    <code>{@link AbstractPropertyTest}</code>.
 * </p>
 *
 * @author Robert Sese
 * @author Brett McLaughlin
 */
public class ContainerPropertyTest extends AbstractContainerTest {

    /**
     * The modifiers (i.e. public, volatile, etc) for the test
     * ContainerProperty.
     */
    private BitSet modifiers;

    /** The test ContainerProperty. */
    private ContainerProperty containerProperty;


    /**
     * Creates a new Container object that will be used to test Container level
     * methods.
     *
     * @return a Container object to test with.
     */
    protected Container createContainer() {
        return new ContainerProperty("",
                                     "my_xml_name",
                                     "my_type_uri",
                                     "my_xml_type");
    }

    /**
     * Constructs an ContainerPropertyTest with the given name.
     */
    public ContainerPropertyTest(String name) {
        super(name);
    }

    /**
     * Returns the test suite for this test case.
     *
     * @return the TestSuite for ContainerProperty test.
     */
    public static Test suite() {
        return new TestSuite(ContainerPropertyTest.class);
    }

    /**
     * Establishes the test fixture.
     */
    protected void setUp() {
        modifiers = new BitSet();
        modifiers.set(Property.ACCESS_PRIVATE);
        modifiers.set(Property.SOURCE_ATTLIST);

        containerProperty = new ContainerProperty("",
                                                  "my_xml_name",
                                                  "my_type_uri",
                                                  "my_xml_type");
    }

    /**
     * Releases any resources.
     */
    protected void tearDown() {
        modifiers = null;
        containerProperty = null;
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor1() {
        ContainerProperty c
            = new ContainerProperty("xml_name_uri",
                                    "xml_name",
                                    "xml_type_uri",
                                    "xml_type",
                                    modifiers);
        assertTrue("Constructor failure", c != null);
    }

    /**
     * Tests a valid construction.
     */
    public void testConstructor3() {
        ContainerProperty c
            = new ContainerProperty("xml_name_uri",
                                    "xml_name",
                                    "xml_type_uri",
                                    "xml_type");
        assertTrue("Constructor failure", c != null);
    }
    
}

