/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * <p>
 *  This is a test case for the <code>{@link ArgumentsTest}</code> class.
 * </p>
 * 
 * @author Brooke Hedrick
 * @author Brett McLaughlin
 */
public class ArgumentsTest extends TestCase {
        
    /**
     * <p>
     *  This constructs a new <code>ArgumentsTest</code>.
     * </p>
     *
     * @param name the name of the test case.
     */
    public ArgumentsTest(String name) {
        super(name);
    }

    /**
     * <p>
     *  This method maeks it easier to call these
     *    tests dynamically.
     * </p>
     *
     * @return <code>TestSuite</code> - corresponds to this 
     *         <code>TestCase</code>.
     */
    public static Test suite(){
        return new TestSuite(ArgumentsTest.class);
    }

    /**
     * <p>
     *  This tests the default constructor for the 
     *    <code>{@link Arguments}</code> class.
     * </p>
     */
    public void testNoParameterConstructor() {
        Arguments arguments = new Arguments();
        assertTrue(arguments != null);
    }

    /**
     * <p>
     *  This tests the constructor 
     *    <code>{@link Arguments(String[] args)}</code>.
     * </p>
     */
    public void testStringArrayConstructor() {
        String[] args = 
            new String[] {"-file=/usr/src/dtd/song.dtd","-quiet=true"};
            
        Arguments arguments = new Arguments(args);
        
        String expected = "/usr/src/dtd/song.dtd";
        assertEquals(arguments.getValue("file"), expected);    

        expected = "true";
        assertEquals(arguments.getValue("quiet"), expected);
    }

    /**
     * <p>
     *  This tests the <code>{@link Arguments#setValue}</code> method.
     * </p>
     */
    public void testSetValue() {
        Arguments arguments = new Arguments();
        
        String expected = "value1";
        arguments.setValue("argument1", expected);
        assertEquals(arguments.getValue("argument1"), expected);
        
        expected = "value2";
        arguments.setValue("argument2", expected);
        assertEquals(arguments.getValue("argument2"), expected);
    }
    
    /**
     * <p>
     *  This tests the <code>{@link Arguments#getValue}</code> method.
     * </p>
     */
    public void testGetValue() {
        Arguments arguments = new Arguments();
        
        String expected = "testValue";
        arguments.setValue("testArgument", expected);
        assertEquals(arguments.getValue("testArgument"), expected);    
    }

    /**
     * <p>
     *  This tests the <code>{@link Arguments#hasValue}</code> method.
     * </p>
     */
    public void testHasValue() {
        Arguments arguments = new Arguments();
        
        arguments.setValue("testArgument", "testValue");
    
        assertTrue(arguments.hasValue("testArgument"));            
        assertTrue(!arguments.hasValue("missingArgument"));
    }

    /**
     * <p>
     *  This tests the <code>{@link Arguments#setValues}</code> method.
     * </p>
     */
    public void testSetValues() {
        String[] args = 
            new String[] {"-file=/usr/src/dtd/song.dtd","-quiet=true"};
            
        Arguments arguments = new Arguments();
        arguments.setValues(args);
        
        String expected = "/usr/src/dtd/song.dtd";
        assertEquals(arguments.getValue("file"), expected);    

        expected = "true";
        assertEquals(arguments.getValue("quiet"), expected);
    }
}

